@@ -10,6 +10,7 @@
 #' @param fill A character string indicating the fill color. If nothing is provided, then "#80bcd8" (light blue) will be used as a default.
 #' @param alpha An optional alpha transparency value for the color as single value in the range of 0 (fully transparent) to 1 (fully opaque). If not provided the fill color will either be fully opaque or use alpha information from the color value if it is supplied in the #RRGGBBAA format.
 #' @param font_weight A string or number indicating the weight of the font. Can be a text-based keyword such as "normal", "bold", "lighter", "bolder", or, a numeric value between 1 and 1000, inclusive. Note that only variable fonts may support the numeric mapping of weight.
+#' @param font_color A character string indicating the text color. If nothing is provided, then "#000000" (black) will be used as a default.
 #' @param bold_target_only A logical of TRUE/FALSE indicating whether to apply bold to only the specific `target_col`. You must indicate a specific column with `target_col`.
 #' @param target_col A specific `tidyeval` column to apply bold text to, which allows for normal weight text for the remaining highlighted columns.
 #' @return An object of class `gt_tbl`.
@@ -42,7 +43,7 @@
 
 gt_highlight_rows <- function(
   gt_object, columns = gt::everything(), rows = TRUE, fill = "#80bcd8",
-  alpha = 0.8, font_weight = "bold", bold_target_only = FALSE, target_col = c()){
+  alpha = 0.8, font_weight = "bold", font_color = '#000000', bold_target_only = FALSE, target_col = c()){
 
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
 
@@ -58,7 +59,7 @@ gt_highlight_rows <- function(
       ) %>%
       tab_style(
         style = list(
-          cell_text(weight = font_weight)
+          cell_text(weight = font_weight, color = font_color)
         ),
         locations = cells_body(
           columns = {{ target_col }},
@@ -70,7 +71,7 @@ gt_highlight_rows <- function(
       tab_style(
         style = list(
           cell_fill(color = fill, alpha = alpha),
-          cell_text(weight = font_weight)
+          cell_text(weight = font_weight, color = font_color)
         ),
         locations = cells_body(
           columns = {{ columns }},
